Weak Method — Kivy v1.0.1-dev documentation

# Weak Method

`WeakMethod` is used in Clock class, to prevent the clock of taking memory if the object is deleted. Check examples/core/clock_method.py for more informations.

This WeakMethod class is taken from the recipe http://code.activestate.com/recipes/81253/, based on the nicodemus version. (thanks to him !)

class `kivy.weakmethod.` `WeakMethod`(method)

  Bases: `object`

  Implementation of weakref for function and bounded method.

  `is_dead`()

    Returns True if the referenced callable was a bound method and the instance no longer exists. Otherwise, return False.